@@ -1,4 +1,3 @@
-local H = wesnoth.require "helper"
 local AH = wesnoth.require "ai/lua/ai_helper.lua"
 local MAIUV = wesnoth.require "ai/micro_ais/micro_ai_unit_variables.lua"
 local WMPF = wesnoth.require "ai/micro_ais/cas/ca_wolves_multipacks_functions.lua"
@@ -33,7 +32,7 @@ function ca_wolves_multipacks_attack:execution(cfg)
 
         -- This repeats until all wolves in a pack have attacked, or none can attack any more
         while keep_attacking_this_pack do
-            local wolves, attacks = {}, {}
+            local wolves = {}
             for _,pack_wolf in ipairs(pack) do
                 -- Wolf might have moved in previous attack -> use id to identify it
                 local wolf = wesnoth.units.find_on_map { id = pack_wolf.id }[1]
@@ -86,7 +85,7 @@ function ca_wolves_multipacks_attack:execution(cfg)
                 end
 
                 -- Find which target can be attacked by the most units, from the most hexes; and rate by fewest HP if equal
-                local max_rating, best_target = - math.huge
+                local max_rating1, best_target = - math.huge, nil
                 for attack_ind,attack in pairs(attack_map_wolves) do
                     local number_wolves, number_hexes = 0, 0
                     for _,w in pairs(attack) do number_wolves = number_wolves + 1 end
@@ -99,7 +98,7 @@ function ca_wolves_multipacks_attack:execution(cfg)
                     -- Also, any target sitting next to a wolf of the same pack that has
                     -- no attacks left is priority targeted (in order to stick with
                     -- the same target for all wolves of the pack)
-                    for xa,ya in H.adjacent_tiles(target.x, target.y) do
+                    for xa,ya in wesnoth.current.map:iter_adjacent(target) do
                         local adj_unit = wesnoth.units.get(xa, ya)
                         if adj_unit then
                             local unit_pack_number = MAIUV.get_mai_unit_variables(adj_unit, cfg.ai_id, "pack_number")
@@ -112,20 +111,20 @@ function ca_wolves_multipacks_attack:execution(cfg)
                         end
                     end
 
-                    if rating > max_rating then
-                        max_rating, best_target = rating, target
+                    if rating > max_rating1 then
+                        max_rating1, best_target = rating, target
                     end
                 end
 
                 -- Now we know the best target and need to attack
                 -- This is done on a wolf-by-wolf basis, the outside while loop taking care of
                 -- the next wolf in the pack on subsequent iterations
-                local max_rating, best_attack = - math.huge
+                local max_rating2, best_attack = - math.huge, nil
                 for _,attack in ipairs(attacks) do
                     if (attack.target.x == best_target.x) and (attack.target.y == best_target.y) then
                         local rating = attack.att_stats.average_hp / 2. - attack.def_stats.average_hp
-                        if (rating > max_rating) then
-                            max_rating, best_attack = rating, attack
+                        if (rating > max_rating2) then
+                            max_rating2, best_attack = rating, attack
                         end
                     end
                 end
