@@ -1,4 +1,4 @@
-#!/usr/bin/env python3
+#!/usr/pkg/bin/python3.12
 
 """
 wmliterator.py -- Python routines for navigating a Battle For Wesnoth WML tree
@@ -24,7 +24,8 @@ Limitations:
 
 from functools import total_ordering
 import sys, re, copy, codecs
-keyPattern = re.compile('(\w+)(,\s?\w+)*\s*=')
+import fnmatch
+keyPattern = re.compile(r'(\w+)(,\s?\w+)*\s*=')
 keySplit = re.compile(r'[=,\s]')
 tagPattern = re.compile(r'(^|(?<![\w|}]))(\[/?\+?[a-z _]+\])')
 macroOpenPattern = re.compile(r'(\{[^\s\}\{]*)')
@@ -377,6 +378,14 @@ Important Attributes:
         """Return a list of tags enclosing this location, outermost first."""
         return tuple([x.element for x in self.scopes])
 
+    def glob_ancestors(self, pattern):
+        """Returns True if at least one ancestor matches the supplied
+        case-sensitive glob pattern"""
+        for scope in self.scopes:
+            if fnmatch.fnmatchcase(scope.element, pattern):
+                return True
+        return False
+
     def hasNext(self):
         """Some loops may wish to check this method instead of calling next()
         and handling StopIteration... note: inaccurate for ScopeIterators"""
